# $Id$

use strict;
use warnings;

use Test::More tests => 14;
use File::Temp qw(tempdir);

use_ok('ObsData');
use_ok('ObsData::Repository');

my $o = ObsData->new('testdata/obsdata-conftest', logfile => "testdata/obsdata.log");

{
    my $or = ObsData::Repository::dir->new(
        { 
            obsdata => $o,
            dir => 'testdata/ohp',
        }
    );

    isa_ok($or, "ObsData::Repository::dir");
    ok($or->logging(0, "FOO%s", "FOO") eq "FOOFOO", "logging return the message properly");
    ok($or->findfile, "can find file");
}

{
    my $callbackwhy;
    my $or = ObsData::Repository::dir::archive->new(
        {
            obsdata => $o,
            dir => 'testdata/ohp',
            archivefile => 'ozone34.gz',
            interative_callback => sub {
                my ($self, $event) = @_;
                $callbackwhy = $event->id;
                if ($callbackwhy eq 'overwrite') {
                    return 1;
                } else {
                    return $self->default_choice($event);
                }
            },
        }
    );
    isa_ok($or, "ObsData::Repository::dir::archive");
    ok($or->load_archive, "Can load an archive");

    # ini status checks
    $or->setvalue('FOO', 'FOO');
    $or->set_data_value('ozone34', 'BAR', 'BAR');
    ok($or->getvalue('FOO') eq 'FOO', "can get a value");
    ok($or->get_data_value('ozone34', 'BAR') eq 'BAR', "can get a value");

    ok($or->do_continue('overwrite', '-', 'a', 'a') eq 1, "Perform do_continue");
    ok($callbackwhy eq 'overwrite', "arg are properly passed to callback");
    ok($or->list_archive, "Can list archive content");
    ok($or->get_data_dest('ozone34'), "Can get data destination");
    ok($or->extract_data('ozone34', undef, '/dev/null'), "Can extract data");
}

